@@ -197,7 +197,7 @@ matrank <- function(X)
     # rank is 1 for vectors
     return(1)
   else if(is.matrix(X)) {
-    s <- La.svd(X,0,0, method="dgesdd")
+    s <- La.svd(X,0,0)
     tol <- max(dim(X)) * s$d[1] * .Machine$double.eps
     r <- sum(s$d>tol)
     return(r)
@@ -401,6 +401,9 @@ findgroup <- function(varid, ndye)
 # From R-2.3.0 La.svd(X,method="dgesvd") is deprecated, so change 
 # it to "dgesdd". Hopefully it will not have problem like before.
 #
+# From R-2.4.0 La.svd(X, method="dgesdd" or "dgesvd") is deprecated, so change
+# it to La.svd(X). method="dgesdd" is the default.
+#
 ###############################################################
   
 pinv <- function(X, tol)
@@ -409,7 +412,7 @@ pinv <- function(X, tol)
     stop("X must be a numeric matrix")
   if (!is.matrix(X)) 
     X <- as.matrix(X)
-  Xsvd <- La.svd(X, method="dgesdd")
+  Xsvd <- La.svd(X)
   
   # find the tolerance
   if(missing(tol))
